# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           log_handler.py
   Description:    日志操作模块
   Author:
   Create Date:    2020/03/24
-------------------------------------------------
   Modify:
                   2020/03/24:
-------------------------------------------------
"""

import os

import logging

from logging.handlers import TimedRotatingFileHandler

# 日志级别
CRITICAL = 50
FATAL = CRITICAL
ERROR = 40
WARNING = 30
WARN = WARNING
INFO = 20
DEBUG = 10
NOTSET = 0

# CURRENT_PATH = os.path.dirname(os.path.abspath(__file__))
# ROOT_PATH = os.path.join(CURRENT_PATH, os.pardir)
# print(CURRENT_PATH)
# LOG_PATH = os.path.join(ROOT_PATH, 'log')
#
# if not os.path.exists(LOG_PATH):
#     os.mkdir(LOG_PATH)


class LogHandler(logging.Logger):
    """
    LogHandler
    """

    def __init__(self, name, log_path='log', level=DEBUG, stream=True, file=True):
        self.name = name
        self.level = level
        self.log_path = log_path
        if not os.path.exists(self.log_path):
            os.mkdir(self.log_path)
        logging.Logger.__init__(self, self.name, level=level)
        if stream:
            self.__setStreamHandler__()
        if file:
            self.__setFileHandler__()

    def __setFileHandler__(self, level=None):
        """
        set file handler
        :param level:
        :return:
        """
        file_name = os.path.join(self.log_path, '{name}.log'.format(name=self.name))
        # 设置日志回滚, 保存在log目录, 一天保存一个文件, 保留15天
        file_handler = TimedRotatingFileHandler(encoding='utf-8', filename=file_name, when='D', interval=1, backupCount=15)
        file_handler.suffix = '%Y%m%d.log'
        if not level:
            file_handler.setLevel(self.level)
        else:
            file_handler.setLevel(level)
        formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s')

        file_handler.setFormatter(formatter)
        self.file_handler = file_handler
        self.addHandler(file_handler)

    def __setStreamHandler__(self, level=None):
        """
        set stream handler
        :param level:
        :return:
        """
        stream_handler = logging.StreamHandler()
        formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s')
        stream_handler.setFormatter(formatter)
        if not level:
            stream_handler.setLevel(self.level)
        else:
            stream_handler.setLevel(level)
        self.addHandler(stream_handler)

    def resetName(self, name):
        """
        reset name
        :param name:
        :return:
        """
        self.name = name
        self.removeHandler(self.file_handler)
        self.__setFileHandler__()


if __name__ == '__main__':
    log = LogHandler('test')
    log.info('this is a test msg')



from __future__ import print_function
import ctypes, sys
import os

def is_admin():
    try:
        return ctypes.windll.shell32.IsUserAnAdmin()
    except:
        return False
if is_admin():

    os.system('start cmd')
    # 将要运行的代码加到这里
else:
    if sys.version_info[0] == 3:
        ctypes.windll.shell32.ShellExecuteW(None, "runas", sys.executable, __file__, None, 1)
    else:#in python2.x
        ctypes.windll.shell32.ShellExecuteW(None, u"runas", unicode(sys.executable), unicode(__file__), None, 1)




# -*- coding: utf-8 -*-
import paramiko
import datetime
import time
for i in range(10000000):
    now_t = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    ip = '54.180.163.206'
    print(ip)
    port = 58252
    user = "root"
    password = "abcd1234."
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    # 建立连接
    ssh.connect(ip,port,user,password,timeout = 10)
    #输入linux命令
    stdin,stdout,stderr = ssh.exec_command("pwd")
    # 输出命令执行结果
    result = stdout.read()
    with open('result.txt', 'a')as f:
        f.write(ip + '---' + now_t + '--connect success--' + str(result).replace('b','').replace('\\n','').replace("'","") + '\n')
        print(str(result).replace('b','').replace('\\n',''))
    time.sleep(300)





# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           send_mail.py
   Description:
   Author:        
   Create Date:    2020/08/07
-------------------------------------------------
   Modify:
                   2020/08/07:
-------------------------------------------------
"""
import yagmail


# 邮件发送
def send_email(contents):
    """
    发送通知邮箱
    :param contents: 邮件内容
    :return: None
    """
    # 链接邮箱服务器
    yag = yagmail.SMTP(user="user@example", password="gmail", host='gmail.com', port=465, smtp_ssl=True)
    # 邮箱正文
    # contents = 'This is the body, and here is just text '
    # 发送邮件

    receiver = ['gamil@gmail.com']
    yag.send(receiver, 'test', contents)
    yag.send()
    print('发送成功！')




if __name__ == '__main__':
    send_email('nihao')


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           kafka_consumer.py
   Description:    kafka 消费者
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
from __future__ import division
import sys
import json
from kafka import KafkaConsumer

KAFKA_TOPIC = 'Dhg'
KAFKA_BROKERS = 'localhost:9092'
topic = 'test_topic'
consumer = KafkaConsumer(bootstrap_servers=KAFKA_BROKERS, auto_offset_reset='earliest')
consumer.subscribe([KAFKA_TOPIC, topic])
try:
    for message in consumer:
        print(message)
        data = json.loads(message.value.decode())
        print(data)
        try:
            for i in json.loads(data['field_1']):
                print(i)
        except:
            pass
        try:
            for j in json.loads(data['field_2']):
                print(j)
        except:
            pass

except KeyboardInterrupt:
    sys.exit()


#! python3
# bulletPointAdder.py
# 复制几行文字， 运行该脚本， 打印结果： 在每行前添加*号
import pyperclip
import time
import datetime

temp = ''
while True:
    now_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    text = pyperclip.paste() # 提取剪切板的文字
    if text == temp:
        pass
    else:
        print('[' + now_time + ']', '复制内容为:', text)

#lines = text.split('\n') # 按每行拆分为列表
#for i in range(len(lines)):
#    lines[i] = '* ' + lines[i] #每个列表中之前加*
#text = '\n'.join(lines) # 按每行进行列表合并
#text='DannyWU'
#pyperclip.copy(text) # 复制到剪切板中
#print('已将剪切板每行文字前添加* ')
    temp = text



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           receive_mail.py
   Description:
   Author:        
   Create Date:    2020/12/04
-------------------------------------------------
   Modify:
                   2020/12/04:
-------------------------------------------------
"""
from mysql.connector import connect
connect()
from datetime import datetime
import imaplib
import email
import time
import quopri
from lxml import etree
from hahaha_utils.mail_date_list import MAIL_DATE_LIST


def aliyun_mail_to_qy_wechat(imapb, flag):
    # while True:
    now = datetime.strftime(datetime.now(), '%Y-%m-%d %H:%M:%S')
    # try:
    t = imapb.select('INBOX')
    typ, data = imapb.search(None, 'ALL')
    all_mails = data[0].decode().split(' ')
    if flag < len(all_mails):
        if flag == 0:
            v_number = 500
        else:
            v_number = len(all_mails) - flag
        flag = len(all_mails)
        print(len(all_mails))

        # 获取最近十封邮件
        recent_mails = all_mails[len(all_mails) - v_number:]
        # 按邮件的索引倒序
        recent_mails.sort(reverse=True)

        for mailNum in recent_mails:
            # print(1111111111111111, mailNum)
            typ, msg_data = imapb.fetch(mailNum, '(RFC822)')
            # print(typ, msg_data)
            response_part = msg_data[0][1]

            # 获取一封邮件的全部内容
            mail_all_content = email.message_from_string(response_part.decode('utf-8'))

            mail_subject = quopri.decodestring(mail_all_content['Subject']).decode().replace('=?utf-8?q?','').replace('=?UTF-8?Q?','').replace('_',' ').replace('?','').replace('=UTF-8q', '').replace('= =UTF-8q', '').replace(' =UTF-8q', '').replace('= ', '')  # .replace('?=', '').replace('=?UTF-8?q?', '').replace('=?UTF-8?q', '')
            mail_from = mail_all_content['From']
            mail_to = mail_all_content['To']

            if '+' in  mail_all_content['Date']:
                mail_date_text = mail_all_content['Date'].split('+')[0].strip()  # print(mail_all_content)
                a = datetime.strptime(mail_date_text, '%a, %d %b %Y %H:%M:%S')
                mail_date = datetime.strftime(a, '%Y-%m-%d %H:%M:%S')
            else:
                mail_date = mail_all_content['Date']

            content_transfer_encoding = mail_all_content['Content-Transfer-Encoding']
            print(now, '**subject: ', mail_subject)
            # if 'monitor.alibabacloud.com' in mail_from and 'Alarm' in mail_subject:
            if 'monitor.alibabacloud.com' in mail_from and ('Alarm' in mail_subject or 'Monitor' in mail_subject) and mail_date not in MAIL_DATE_LIST:


                # print('现在是：', now)
                print(
                    '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
                print('**subject: ', mail_subject)
                print('**mail_from', mail_from)
                print('**mail_to', mail_to)
                print('**mail_date', mail_date)
                print('**content_transfer_encoding', content_transfer_encoding)
                payload = mail_all_content.get_payload()
                # print(payload)
                content = payload[0]
                # print(content)
                # try:
                # mail_content = base64.b64decode(str(content).split('base64')[-1].strip()).decode()
                # if 'Alibaba Cloud Monitor' in str(content):
                # print(mail_content)
                mail_html = quopri.decodestring(str(content)).decode()
                print('##############################################################################')
                # print(mail_html)
                html = etree.HTML(mail_html)
                with open(str(mail_date).replace(':', '').replace('+','').replace('(CST)','').replace(',','')+'.html', 'w', encoding='utf-8')as f:
                    f.write(str(mail_html).split('quoted-printable')[-1])
                    f.close()
                td_s = html.xpath('//tr[3]//td/text()')
                a_s = html.xpath('//tr[3]//a')
                # print(td_s)
                send_text = ''
                for td in td_s[:-1]:
                    # if 'Alibaba' in td:
                    td_text = td.strip()
                    if td_text != '':
                        # print(td_text)
                        send_text = send_text + td_text + '\n'
                for a in a_s:
                    a_text = a.xpath('./text()')[0].strip() + '\n'
                    a_href = a.xpath('./@href')[0].strip() + '\n'
                    send_text = send_text + a_text + a_href
                print('1111111111111111111111111111111111111111')
                print(send_text)
                MAIL_DATE_LIST.append(mail_date)
                print('mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm', MAIL_DATE_LIST)
        with open('mail_date_list.py', 'w')as f:
            f.write('MAIL_DATE_LIST = {}'.format(MAIL_DATE_LIST))
            f.close()
        print('###########################################################################################')
        time.sleep(1)
    else:
        print('现在是：', now)
        print('目前没有新的邮件!')
        print('###########################################################################################')
        time.sleep(1)
        # except:
        #     imapb = imaplib.IMAP4_SSL('imap.exmail.qq.com', port=993)
        #     imapb.login('danny@kreditme.id', 'Xiaoqiang123')
        #     print('已经重新登录！')
    return flag


if __name__ == '__main__':

    flag = 0
    imapb = imaplib.IMAP4_SSL('exmail.qq.com', port=993)
    imapb.login('user@example.id', 'example')
    while True:
        try:
            flag_1 = aliyun_mail_to_qy_wechat(imapb, flag)
            flag = flag_1
            print(flag)
        except Exception as e:
            print('错误信息', e)
            now_time = datetime.strftime(datetime.now(), '%Y-%m-%d %H:%M:%S')
            try:
                imapb = imaplib.IMAP4_SSL('exmail.qq.com', port=993)
                imapb.login('user@example.id', 'example')
                print('重新登陆成功！')
                with open('login_success_log.log', 'a', encoding='utf-8') as f:
                    f.write(now_time + ' 重新登陆成功！\n')
                    f.close()
            except Exception as e:
                print('错误信息', e)
                print(now_time + '重新登陆失败！')
                with open('login_fail_log.log', 'a', encoding='utf-8') as f:
                    f.write(now_time + ' 重新登陆失败！\n')
                    f.close()
                pass



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           header_pretty.py
   Description:    请求头格式化
   Author:        
   Create Date:    2020/04/30
-------------------------------------------------
   Modify:
                   2020/04/30:
-------------------------------------------------
"""
import json


def header_pretty(headers):

    # 去除参数头尾的空格并按换行符分割
    headers = headers.strip().split('\n')

    # 使用字典生成式将参数切片重组，并去掉空格，处理带协议头中的://
    headers = {x.split(':')[0].strip(): ("".join(x.split(':')[1:])).strip().replace('//', "://") for x in headers}

    # 使用json模块将字典转化成json格式打印出来
    new_headers = json.dumps(headers, indent=1)
    # new_headers = headers
    return json.loads(new_headers)


if __name__ == '__main__':
    headers = """
content-type: application/x-www-form-urlencoded; charset=UTF-8
cookie: abcdefghijklmnopqrst
dnt: 1
if-modified-since: Thu, 01 Jan 1970 00:00:00 GMT
origin: https://example.com
referer: https://example.com/hotel/shanghai2
sec-fetch-dest: empty
sec-fetch-mode: cors
sec-fetch-site: same-origin
user-agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.125 Safari/537.36
    """
    header = header_pretty(headers)
    print(header)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           aes_encrypt.py
   Description:    AES加密解密实现
   Author:        
   Create Date:    2020/07/30
-------------------------------------------------
   Modify:
                   2020/07/30:
-------------------------------------------------
"""
from Crypto.Cipher import AES
import base64


def aes_encrypt(key, data):
    """
    AES的ECB模式加密方法
    :param key: 密钥
    :param data: 被加密字符串（明文）
    :return: 密文
    """

    # Bytes
    BLOCK_SIZE = 16

    # 字符串补位
    pad = lambda s:\
        s + (BLOCK_SIZE - len(s) % BLOCK_SIZE) * chr(BLOCK_SIZE - len(s) % BLOCK_SIZE)

    key = key.encode('utf8')
    data = pad(data)
    cipher = AES.new(key, AES.MODE_ECB)
    # 加密后得到的是bytes类型的数据，使用Base64进行编码,返回byte字符串
    result = cipher.encrypt(data.encode())
    encode_str = base64.b64encode(result)
    enc_text = encode_str.decode('utf8')
    return enc_text


def aes_decrypt(key, data):
    """
    AES解密
    :param key: 密钥
    :param data: 加密后的数据（密文
    :return: 明文
    """

    # 去补位
    unpad = lambda s: s[:-ord(s[len(s) - 1:])]

    key = key.encode('utf8')
    data = base64.b64decode(data)
    cipher = AES.new(key, AES.MODE_ECB)

    text_decrypted = unpad(cipher.decrypt(data))
    text_decrypted = text_decrypted.decode('utf8')
    return text_decrypted


if __name__ == '__main__':
  pass




# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           image_handler.py
   Description:
   Author:        
   Create Date:    2020/07/15
-------------------------------------------------
   Modify:
                   2020/07/15:
-------------------------------------------------
"""

import numpy as np
from PIL import Image
import matplotlib.pyplot as plt
import cv2
import random
import scipy.misc
import scipy.signal
import scipy.ndimage
from matplotlib.font_manager import FontProperties

class ImageHandler(object):

    def noise_remove_cv2(self, image_name, k):
        """
        8邻域降噪
        Args:
            image_name: 图片文件命名
            k: 判断阈值

        Returns:

        """

        def calculate_noise_count(img_obj, w, h):
            """
            计算邻域非白色的个数
            Args:
                img_obj: img obj
                w: width
                h: height
            Returns:
                count (int)
            """
            count = 0
            width, height = img_obj.shape
            for _w_ in [w - 1, w, w + 1]:
                for _h_ in [h - 1, h, h + 1]:
                    if _w_ > width - 1:
                        continue
                    if _h_ > height - 1:
                        continue
                    if _w_ == w and _h_ == h:
                        continue
                    if img_obj[_w_, _h_] < 240:  # 二值化的图片设置为255
                        count += 1
            return count

        img = cv2.imread(image_name, 1)
        # 灰度
        gray_img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
        w, h = gray_img.shape
        for _w in range(w):
            for _h in range(h):
                if _w == 0 or _h == 0:
                    gray_img[_w, _h] = 255
                    continue
                # 计算邻域pixel值小于255的个数
                pixel = gray_img[_w, _h]
                if pixel == 255:
                    continue

                if calculate_noise_count(gray_img, _w, _h) < k:
                    gray_img[_w, _h] = 255
        return gray_img

    def image_gray(self):
        from PIL import Image

        #  load a color image
        im = Image.open('./test/514951_id_front2860F9AB-4DB9-4FB0-944E-3C53BD03545A.jpg')  # 当前目录创建picture文件夹

        #  convert to grey level imageL
        # Lim = im.convert('L')

        # # 浮点算法
        # im = np.array(im)
        # im[:, :, 0] = im[:, :, 0] * 0.3
        # im[:, :, 1] = im[:, :, 1] * 0.59
        # im[:, :, 2] = im[:, :, 2] * 0.11
        # im = np.sum(im, axis=2)

        # # 整数算法
        # im = np.array(im, dtype=np.float32)
        # im[..., 0] = im[..., 0] * 30.0
        # im[..., 1] = im[..., 1] * 59.0
        # im[..., 2] = im[..., 2] * 11.0
        # im = np.sum(im, axis=2)
        # im[..., :] = im[..., :] / 100.0

        # # 平均值算法
        # im = np.array(im, dtype=np.float32)
        # im = np.sum(im, axis=2)
        # im[..., :] = im[..., :] / 3.0

        # # 位移法
        # im = np.array(im, dtype=np.int32)
        # im[..., 0] = im[..., 0] * 28.0
        # im[..., 1] = im[..., 1] * 151.0
        # im[..., 2] = im[..., 2] * 77.0
        # im = np.sum(im, axis=2)
        # arr = [np.right_shift(y.item(), 8) for x in im for y in x]
        # arr = np.array(arr)
        # arr.resize(im.shape)

        # # 单通道法（只取绿色通道）
        # im = np.array(im, dtype=np.int32)
        # im[..., 0] = 0
        # im[..., 2] = 0
        # im = np.sum(im, axis=2)

        #    ++++++++++++二值化+++++++++++++++
        # # 取中间阀值
        # im = np.array(im.convert('L'))
        # im = np.where(im[..., :] < 127, 0, 255)

        # # 取所有像素点灰度的平均值
        # im_gray1 = im.convert('L')
        # im_gray1 = np.array(im_gray1)
        # avg_gray = np.average(im_gray1)
        # im = np.where(im_gray1[..., :] < avg_gray, 0, 255)

        #    ++++++++++++灰度变换+++++++++++++++
        # # 反相
        # im_gray = im.convert('L')
        # im_arr = np.array(im_gray)
        # im = 255 - im_arr

        # # 将像素值变换到100~200之间
        # im_gray = im.convert('L')
        # im_arr = np.array(im_gray)
        # print(im_gray)
        # im = (100.0 / 255) * im_arr + 100
        # self.showimg(Image.fromarray(im))

        # 将像素值求平方，使较暗的像素值变得更小
        im_gray = im.convert('L')
        im_arr = np.array(im_gray)
        im = 255.0 * (im_arr / 255.0) ** 2
        self.showimg(Image.fromarray(im))



        self.showimg(Image.fromarray(im), isgray=True)
        # Lim.save('./test/pice.jpg')

        # #  setup a converting table with constant threshold
        # threshold = 115
        # table = []
        # for i in range(256):
        #     if i < threshold:
        #         table.append(0)
        #     else:
        #         table.append(1)
        #
        # # convert to binary image by the table
        # bim = Lim.point(table, '1')
        #
        # bim.save('./test/picf.png')

    # 获取图片
    def get_image(self, image_path):
        image = Image.open(image_path)

        return image

    # 显示图片
    def showimg(self, image, isgray=False):
        # image =
        plt.axis("off")
        if isgray == True:
            plt.imshow(image, cmap='gray')
        else:
            plt.imshow(image)
        plt.imshow(image)
        plt.show()


if __name__ == '__main__':
    ih = ImageHandler()
    image = ih.get_image('./test/514951_id_front2860F9AB-4DB9-4FB0-944E-3C53BD03545A.jpg')
    # ih.showimg(image)

    # ih.image_gray()

    image = ih.noise_remove_cv2("./test/514951_id_front2860F9AB-4DB9-4FB0-944E-3C53BD03545A.jpg", 4)
    cv2.imshow('img', image)


    cv2.waitKey(100000)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           pdf_to_picture.py
   Description:
   Author:        
   Create Date:    2020/05/03
-------------------------------------------------
   Modify:
                   2020/05/03:
-------------------------------------------------
"""
# pip install fitz,
# pip install PyMuPDF
import sys, fitz
import os
import datetime


def pyMuPDF_fitz(pdfPath, imagePath):
    startTime_pdf2img = datetime.datetime.now()  # 开始时间

    print("imagePath=" + imagePath)
    pdfDoc = fitz.open(pdfPath)
    for pg in range(pdfDoc.pageCount):
        page = pdfDoc[pg]
        rotate = int(0)
        # 每个尺寸的缩放系数为1.3，这将为我们生成分辨率提高2.6的图像。
        # 此处若是不做设置，默认图片大小为：792X612, dpi=96
        zoom_x = 1.33333333  # (1.33333333-->1056x816)   (2-->1584x1224)
        zoom_y = 1.33333333
        mat = fitz.Matrix(zoom_x, zoom_y).preRotate(rotate)
        pix = page.getPixmap(matrix=mat, alpha=False)

        if not os.path.exists(imagePath):  # 判断存放图片的文件夹是否存在
            os.makedirs(imagePath)  # 若图片文件夹不存在就创建

        pix.writePNG(imagePath + '/' + 'images_%s.png' % pg)  # 将图片写入指定的文件夹内

    endTime_pdf2img = datetime.datetime.now()  # 结束时间
    print('pdf2img时间=', (endTime_pdf2img - startTime_pdf2img).seconds)


if __name__ == "__main__":
    pdfPath = "E:\\Users\\Danny\\Desktop\\PRESS_RELEASE_COVID-19,_SABTU_2_MEI_2020.pdf"
    imagePath = 'a'
    pyMuPDF_fitz(pdfPath, imagePath)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           rabbit_mq_consumer.py
   Description:    RabbitMQ 消费者
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
import pika
queue = 't_strategy_decision_record_xx_db_t_rc_decision_record_y'
credentials = pika.PlainCredentials('guest', 'root')
connection = pika.BlockingConnection(
    pika.ConnectionParameters(host='localhost', port=5672, credentials=credentials))
channel = connection.channel()

channel.queue_declare(queue=queue, durable = True)


def callback(ch, method, properties, body):
    # print(method.delivery_tag)
    # ch.basic_ack(delivery_tag=method.delivery_tag)
    print(body.decode())
    # print(" [x] Received %r" % body)
    # print(properties)


channel.basic_consume(
    queue=queue, on_message_callback=callback, auto_ack=True)

print(' [*] Waiting for messages. To exit press CTRL+C')
channel.start_consuming()


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           rabbit_mq_producer.py
   Description:    RabbitMQ 生产者
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
import pika
import json

credentials = pika.PlainCredentials('guest', 'root')  # mq用户名和密码
# 虚拟队列需要指定参数 virtual_host，如果是默认的可以不填。
connection = pika.BlockingConnection(
    pika.ConnectionParameters(host='localhost', port=5672, credentials=credentials))
channel = connection.channel()
# 声明消息队列，消息将在这个队列传递，如不存在，则创建
result = channel.queue_declare(queue='hello', durable = True)

for i in range(10):
    message = json.dumps({'OrderId': "1000%s" % i})
    # 向队列插入数值 routing_key是队列名
    channel.basic_publish(exchange='', routing_key='hello', body=message)
    print(message)
connection.close()



import subprocess

while True:
    try:
        cmd = input("#: ")
        if 'cd ' in cmd:
            cmd = input(cmd.split('cd ')[-1] + '>')
        (status, return_data) = subprocess.getstatusoutput(cmd)
        for i in return_data.split('\\n'):
            print(i)
    except:
        pass



import sys

from colorama import init
init(strip=not sys.stdout.isatty()) # strip colors if stdout is redirected
from termcolor import cprint 
from pyfiglet import figlet_format

def print_ascii_tetx(font_text):


       cprint(figlet_format(font_text, font='starwars'), 'green', 'on_red', attrs=['bold'])

if __name__ == '__main__':
       font_text = 'abcd'
       print_ascii_tetx(font_text)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           kafka_producter.py
   Description:    kafka 生产者
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
from __future__ import division
import json
import base64
import datetime
from kafka import KafkaProducer

TS = str(datetime.datetime.now().strftime('%Y%m%d%H%M%S'))
files = {
    "name": 'test_content',
    "data": 'Data'
}
producer = KafkaProducer(
    value_serializer=lambda v: json.dumps(v).encode('utf-8'),
    bootstrap_servers='localhost:9092'
)
for i in range(300000):
    print('i: ', files)
    producer.send('test', files)
producer.close()


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           excel_handler.py
   Description:
   Author:        
   Create Date:    2020/06/23
-------------------------------------------------
   Modify:
                   2020/06/23:
-------------------------------------------------
"""
import pandas as pd

class ExcelHandler(object):
    def __init__(self):
        pass

    def read_excel_file(self, file_path, *args, **kwargs):
        """

        :param file_path:
        :param args:
        :param kwargs:
        :return:
        """
        self.file_content = pd.read_excel(file_path, **kwargs)
        return self.file_content

    def write_excel_file(self, file_path, data_list, columns, *args, **kwargs):
        """

        :param file_path:
        :param data_list:
        :param columns:
        :param args:
        :param kwargs:
        :return:
        """
        df = pd.DataFrame(data_list, columns=columns)
        df.to_excel(file_path, **kwargs)
        return 1

if __name__ == '__main__':
    eh = ExcelHandler()
    file_content = eh.read_excel_file("E:\\Users\\Danny\\Desktop\\test.xlsx")
    print(file_content)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           es_client.py
   Description:
   Author:        
   Create Date:    2021/04/25
-------------------------------------------------
   Modify:
                   2021/04/25:
-------------------------------------------------
"""
from elasticsearch import Elasticsearch
from hahaha_utils.log_handler import LogHandler

class ES_Client(object):
    def __init__(self,es_host, http_auth=None):
        self.log = LogHandler('es')
        self.es = Elasticsearch(es_host, http_auth=http_auth)

    def fetch_data(self, index, size, body):
        data_list = []

        try:
            results = self.es.search(index=index, size=size, body=body)['hits']['hits']
            for data in results:
                data_list.append(data)
        except Exception as e:
            self.log.info('数据查询失败: ' + str(e))
        
        return data_list


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           rabbit_mq_exchange_consumer.py
   Description:
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
# -*- coding: utf-8 -*-
import pika
import sys
import json

hostname = '192.168.15.75'
port = 5672
username = 'guest'
password = 'root'
exchange = 'lepin.etl.topic'
queue = 't_rc_order_xx_yy_db_t_rc_order_z'
queue1 = 'rc_manual_xx_yy_db_t_rc_order_manual_z'

credentials = pika.PlainCredentials(username=username, password=password)
parameters = pika.ConnectionParameters(host=hostname,port=port,credentials=credentials)
connection = pika.BlockingConnection(parameters=parameters)#创建连接

channel = connection.channel()
channel.exchange_declare(exchange=exchange, exchange_type='topic', durable=True)

result = channel.queue_declare(exclusive=False, queue=queue, durable=True)
channel.queue_declare(exclusive=False, queue=queue1, durable=True)

#绑定键。‘#’匹配所有字符，‘*’匹配一个单词
binding_key = queue

# if not binding_keys:
#     sys.stderr.write("Usage: %s [binding_key]...\n" % sys.argv[0])
#     sys.exit(1)

# for binding_key in binding_keys:
#     print(binding_key)

channel.queue_bind(exchange=exchange, queue=queue, routing_key=binding_key)

print('[*] Writing for logs. To exit press CTRL+C.')


def parse(data):
    json_data = json.loads(data)
    json_data['fcreate_time'] = json_data['fcreate_time'].replace('T', ' ').replace('.000Z', '')
    json_data['fapproval_suc_time'] = json_data['fapproval_suc_time'].replace('T', ' ').replace('.000Z', '')
    json_data['fmodify_time'] = json_data['fmodify_time'].replace('T', ' ').replace('.000Z', '')
    try:
        json_data['fnext_follow_time'] = json_data['fnext_follow_time'].replace('T', ' ').replace('.000Z', '')
    except Exception as e:
        print(e)

    try:
        json_data['flast_modify_time'] = json_data['flast_modify_time'].replace('T', ' ').replace('.000Z', '')
    except Exception as e:
        print(e)
    print(json_data)

def callback(ch, method, properties, body):
    # print(ch)
    # print(method)
    # print(properties)
    # print(method.routing_key, body.decode())
    data = body.decode()
    parse(data)



# channel.basic_consume(on_message_callback=callback, queue='rc_manual_xx_yy_db_t_rc_order_manual_z', auto_ack=True)
channel.basic_consume(on_message_callback=callback, queue=queue, auto_ack=True)
channel.basic_consume(on_message_callback=callback, queue=queue1, auto_ack=True)
channel.start_consuming()



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           setup.py
   Description:
   Author:        
   Create Date:    2020/04/09
-------------------------------------------------
   Modify:
                   2020/04/09:
-------------------------------------------------
"""
from distutils.command.install import INSTALL_SCHEMES
from setuptools import setup, find_packages
from setuptools.command.install import install


for scheme in INSTALL_SCHEMES.values():
    scheme['data'] = scheme['purelib']

setup_args = {
    'cmdclass': {'install': install},
    'name': 'hahaha_utils',
    'author': 'Danny',
    'author_email': 'mrdanny1024@gmail.com',
    'version': "1.0.7",
    'license': 'MIT',
    'description': 'HAHAHA Python3 Utils',
    'long_description': 'HAHAHA Python3 Utils',
    'url': 'https://www.idannywu.com',
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
    'classifiers': [
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    'package_dir': {
        'hahaha_utils': 'hahaha_utils',
        # 'hahaha_utils.config': 'hahaha_utils/config',
        # 'hahaha_utils.db_utils': 'hahaha_utils/db_utils',
        # 'hahaha_utils.log_handler': 'hahaha_utils/log_handler',
        # 'hahaha_utils.web_request': 'hahaha_utils/web_request'
    },
    'packages': [
        'hahaha_utils',
        # 'hahaha_utils.config',
        # 'hahaha_utils.db_utils',
        # 'hahaha_utils.log_handler',
        # 'hahaha_utils.web_request',
    ],
    # 'packages': find_packages(where="src"),
    'include_package_data': True,
    'install_requires': [
        'pika',
        'pandas',
        'matplotlib',
        'colorama',
        'yagmail',
        'termcolor',
        'camelot_py',
        'requests',
        'kafka_python',
        'pyperclip',
        'lxml',
        'fitz',
        'baidu_aip',
        'scipy',
        'PyMySQL',
        'pyfiglet',
        'opencv_python',
        'numpy',
        'wheel',
        'paramiko',
        'camelot',
        'kafka',
        'Pillow',
        'pip',
        'pycryptodome',
        'elasticsearch'
    ],
    'zip_safe': False
}

setup(**setup_args)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           mysql_client.py
   Description:    MySQL数据库工具类封装
   Author:
   Create Date:    2020/03/24
-------------------------------------------------
   Modify:
                   2020/03/24:a
-------------------------------------------------
"""

from pymysql import connect as conn
from hahaha_utils.log_handler import LogHandler

class MySQLClient(object):
    def __init__(self, db_host, db_user, db_password, db_name, db_port, **kwargs):
        """
        连接数据库方法
        :param db_host: MySQL数据库所在的主机
        :param db_user: 用户名
        :param db_pass: 密码
        :param database: 要连接的数据库
        :param db_port: MySQL数据库的端口
        :return: 连接对象
        """
        self.log = LogHandler('db')
        try:
            self.__connect = conn(host=db_host, user=db_user, password=db_password, db=db_name, port=db_port)
            self.__cursor = self.__connect.cursor()
        except Exception as e:
            self.log.info('数据库链接失败: ' + str(e))
        # print(self.connect)

    def get_connect(self):
        # 获取连接
        return self.__connect

    def get_cursor(self):
        # 获取游标
        return self.__cursor

    def commit(self):
        # 提交事务
        self.__connect.commit()

    def close(self):
        """
        关闭游标对象和连接对象
        """
        try:
            if self.__cursor != None:
                self.__cursor.close()
            if self.__connect != None:
                self.__connect.close()
        except Exception as e:
            self.log.info('数据库关闭失败: ' + str(e))
        return True

    def __edit(self, sql, params):
        """
        执行增删改
        :param sql: sql语句
        :param params: sql语句对象的参数列表，默认值为None
        :return: 受影响的行数
        """
        count = 0
        try:
            count = self.__cursor.execute(sql, params)
            self.__connect.commit()
        except Exception as e:
            self.log.info('数据库操作失败: ' + str(e))
        return count

    def update(self, sql, params=None):
        '''
        执行修改
        :param sql: sql语句
        :param params: sql语句对象的参数列表，默认值为None
        :return: 受影响的行数
        '''
        return self.__edit(sql, params)

    def insert_one(self, sql, params=None):
        '''
        执行新增
        :param sql: sql语句
        :param params: sql语句对象的参数列表，默认值为None
        :return: 受影响的行数
        '''
        return self.__edit(sql, params)

    def insert_many(self, sql, params):
        """
        一次插入多条数据
        :param sql:
        :param values:
        :return:
        """
        try:
            self.__cursor.executemany(sql, params)
            self.__connect.commit()
        except Exception as e:
            self.log.info('插入多条数据失败: ' + str(e))

    def delete(self, sql, params=None):
        '''
        执行删除
        :param sql: sql语句
        :param params: sql语句对象的参数列表，默认值为None
        :return: 受影响的行数
        '''
        return self.__edit(sql, params)


    def fetch_count(self, sql, params=None):
        """
        查询一共有多少条数据
        :param connect:
        :param sql:
        :return:
        """
        data_count = -1
        try:
            data_count = self.__cursor.execute(sql, params)
        except Exception as e:
            self.log.info('查询数据总量错误: ' + str(e))
        return data_count

    def fetch_all(self, sql, params=None):
        """
        查询所有结果
        :param connect:
        :param sql:
        :return:
        """
        data_list = []
        try:
            count = self.__cursor.execute(sql, params)
            if count != 0:
                data_list = self.__cursor.fetchall()
        except Exception as e:
            self.log.info('查询失败: ' + str(e))
        return data_list

    def fetch_one(self, sql, params=None):
        """
        查询所有结果
        :param connect:
        :param sql:
        :return:
        """
        data_list = []
        try:
            count = self.__cursor.execute(sql, params)
            if count != 0:
                data_list = self.__cursor.fetchone()
        except Exception as e:
            self.log.info('查询失败: ' + str(e))
        return data_list

    def fetch_all_table_field(self, table_name, params=None):
        """
        获取表的所有字段
        :param table_name:
        :param params:
        :return:
        """
        sql = 'show full columns from {}'.format(table_name)
        field_list = self.fetch_all(sql, params=params)

        table_field = {}
        for j in field_list:
            field_name = j[0]
            field_type = j[1]

            table_field[field_name] = field_type

        return table_field

    def fetch_all_table_name(self, params=None):
        """
        获取数据库里的所有表名
        :param params:
        :return:
        """
        results = self.fetch_all('show tables', params=params)
        table_name_list = []
        for i in results:
            table_name_list.append(i[0])

        return table_name_list


if __name__ == '__main__':
    pass



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           web_request.py
   Description:    请求页面
   Author:
   Create Date:    2020/03/24
-------------------------------------------------
   Modify:
                   2020/03/24:
-------------------------------------------------
"""

from requests.models import Response
import requests
import random
import time
from json import dumps
from hahaha_utils.log_handler import LogHandler


class WebRequest(object):
    def __init__(self, *args, **kwargs):
        # pass
        self.log = LogHandler('web_request')

    @property
    def user_agent(self):
        """
        return an User-Agent at random
        :return:
        """
        ua_list = [
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.101',
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.122',
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71',
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95',
            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.71',
            'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; QQDownload 732; .NET4.0C; .NET4.0E)',
            'Mozilla/5.0 (Windows NT 5.1; U; en; rv:1.8.1) Gecko/20061208 Firefox/2.0.0 Opera 9.50',
            'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:34.0) Gecko/20100101 Firefox/34.0',
        ]
        return random.choice(ua_list)

    @property
    def header(self):
        """
        basic header
        :return:
        """
        return {'User-Agent': self.user_agent,
                'Accept': '*/*',
                'Connection': 'keep-alive',
                'Accept-Language': 'zh-CN,zh;q=0.8'}

    def get(self, url, header=None, retry_time=5, timeout=30,
            retry_flag=list(), retry_interval=5, *args, **kwargs):
        """
        get method
        :param url: target url
        :param header: headers
        :param retry_time: retry time when network error
        :param timeout: network timeout
        :param retry_flag: if retry_flag in content. do retry
        :param retry_interval: retry interval(second)
        :param args:
        :param kwargs:
        :return:
        """
        headers = self.header
        if header and isinstance(header, dict):
            headers.update(header)
        while True:
            try:
                html = requests.get(url, headers=headers, timeout=timeout, **kwargs)
                if any(f in html.content for f in retry_flag):
                    raise Exception
                return html
            except Exception as e:
                self.log.info('requests get请求错误: ' + str(e) + ' ' + url)
                retry_time -= 1
                if retry_time <= 0:
                    # 多次请求失败
                    resp = Response()
                    # 自定义失败状态码
                    resp.status_code = 8888
                    return resp
                time.sleep(retry_interval)

    def post(self, url, header=None, data=None, retry_time=5, timeout=30,
            retry_flag=list(), retry_interval=5, *args, **kwargs):
        """
        get method
        :param url: target url
        :param header: headers
        :param retry_time: retry time when network error
        :param timeout: network timeout
        :param retry_flag: if retry_flag in content. do retry
        :param retry_interval: retry interval(second)
        :param args:
        :param kwargs:
        :return:
        """
        headers = self.header
        if header and isinstance(header, dict):
            headers.update(header)

        try:
            if 'application/json' in header['content-type'] :
                data = dumps(data)
        except:
            try:
                if 'application/json' in header['Content-Type']:
                    data = dumps(data)
            except Exception as e:
                pass
        # print(data)
        while True:
            try:
                html = requests.post(url, headers=headers, data=data, timeout=timeout, **kwargs)
                if any(f in html.content for f in retry_flag):
                    raise Exception
                return html
            except Exception as e:
                self.log.info('requests post请求错误: ' + str(e) + ' ' + url)
                retry_time -= 1
                if retry_time <= 0:
                    # 多次请求失败
                    resp = Response()
                    resp.status_code = 8888
                    return resp
                time.sleep(retry_interval)

if __name__ == '__main__':
    pass



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           下载jetbrains_active_code
   Description:
   Author:        
   Create Date:    2020/09/27
-------------------------------------------------
   Modify:
                   2020/09/27:
-------------------------------------------------
"""
from zipfile import ZipFile
from requests import get
from os import remove
from time import sleep


def download_jetbrains_active_code(zip_file_name):
    d_url = 'http://idea.medeming.com/jihuoma/images/jihuoma.zip'
    try:
        resp = get(d_url)
        with open(zip_file_name, 'wb')as f:
            f.write(resp.content)
            f.close()
        print()
        # print('jetbrains_active_code.zip 下载成功！')
    except Exception as e:
        print('网络错误：', e)

def read_zip_file(zip_file):
    try:
        z = ZipFile(zip_file, 'r')
        # 打印zip文件中的文件列表
        for file_name in z.namelist():
            if '2018' in file_name:
                content = z.read(file_name).decode()
                active_code_text = ''
                print('您的jetbrains激活码为: ')
                print()
                # print(len(active_code_text))
                # print(active_code_text)
                for i in range(50):
                    start = 150 * i
                    end = 150 * (i + 1)
                    # print(start, end)
                    if content[start: end].strip() != '':
                        active_code_text = active_code_text + content[start: end].strip() + '\n'
                print(active_code_text.strip())
        z.close()
        remove(zip_file)
        print()
        print('祝您生活愉快！')

    except Exception as e:
        print('打开压缩包出现错误：', e)

if __name__ == '__main__':
    zip_file_name = 'jetbrains_active_code.zip'
    download_jetbrains_active_code(zip_file_name)
    read_zip_file(zip_file_name)
    sleep(1000000)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           __init__.py.py
   Description:   乐品星河Python工具包
   Author:        Danny
   Create Date:    2020/04/10
-------------------------------------------------
   Modify:
                   2020/04/10:
-------------------------------------------------
"""
from hahaha_utils.mysql_client import MySQLClient
from hahaha_utils.log_handler import LogHandler
from hahaha_utils.web_request import *
from hahaha_utils.config_loca import *
from hahaha_utils.config_inte import *
from hahaha_utils.config_test import *
from hahaha_utils.config_prod import *


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           baidu_ocr.py
   Description:
   Author:        
   Create Date:    2020/05/03
-------------------------------------------------
   Modify:
                   2020/05/03:
-------------------------------------------------
"""
from aip import AipOcr

""" 你的 APPID AK SK """
APP_ID = '19707944'
API_KEY = 'qZGpPNQwD7pglY8Epkk5sLff'
SECRET_KEY = '3oGp9iDCVTrlGvkqHG9QXfkGkWoATSXd'

client = AipOcr(APP_ID, API_KEY, SECRET_KEY)
print(client)

""" 读取图片 """
def get_file_content(filePath):
    with open(filePath, 'rb') as fp:
        return fp.read()

image = get_file_content("./asdf.png")

""" 调用通用文字识别（高精度版） """
client.basicAccurate(image)

""" 如果有可选参数 """
options = {}
# options["detect_direction"] = "true"
# options["probability"] = "true"

""" 带参数调用通用文字识别（高精度版） """
a = client.basicAccurate(image, options)
print(a)


# """ 读取图片 """
# def get_file_content(filePath):
#     with open(filePath, 'rb') as fp:
#         return fp.read()
#
# image = get_file_content("./dsfs.png")
#
# """ 调用通用文字识别, 图片参数为本地图片 """
# client.basicGeneral(image)
#
# """ 如果有可选参数 """
# options = {}
# # options["language_type"] = "CHN_ENG"
# # options["detect_direction"] = "true"
# # options["detect_language"] = "true"
# # options["probability"] = "true"
#
# """ 带参数调用通用文字识别, 图片参数为本地图片 """
# a = client.basicGeneral(image, options)
#
# # url = "https//www.x.com/sample.jpg"
# #
# # """ 调用通用文字识别, 图片参数为远程url图片 """
# # client.basicGeneralUrl(url)
# #
# # """ 如果有可选参数 """
# # options = {}
# # options["language_type"] = "CHN_ENG"
# # options["detect_direction"] = "true"
# # options["detect_language"] = "true"
# # options["probability"] = "true"
# #
# # """ 带参数调用通用文字识别, 图片参数为远程url图片 """
# # a = client.basicGeneralUrl(image, options)
# print(a)



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           rabbit_mq_exchange_producter.py
   Description:
   Author:        
   Create Date:    2020/08/04
-------------------------------------------------
   Modify:
                   2020/08/04:
-------------------------------------------------
"""
# -*- coding: utf-8 -*-

import pika

hostname = '192.168.15.75'
port = 5672
username = 'guest'
password = 'root'
routing_key = 'test_routing'
credentials = pika.PlainCredentials(username=username, password=password)
parameters = pika.ConnectionParameters(host=hostname, port=port, credentials=credentials)
connection = pika.BlockingConnection(parameters=parameters)  # 创建连接

channel = connection.channel()

# 创建模糊匹配的exchange
channel.exchange_declare(exchange='data_sync', exchange_type='topic', durable=True)

# 这里关键字必须为点号隔开的单词，以便于消费者进行匹配。
routing_key = routing_key
# routing_key = '[warn].kern'

message = 'Hello World!'
channel.basic_publish(exchange='data_sync', routing_key=routing_key, body=message)

print('[生产者] Send %r:%r' % (routing_key, message))
connection.close()



# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           csv_to_excel.py
   Description:
   Author:        
   Create Date:    2020/11/18
-------------------------------------------------
   Modify:
                   2020/11/18:
-------------------------------------------------
"""
import time
import pandas as pd

def csv_to_excel_fun(file_name):
    csv_file_name = file_name.replace('\\', '/').replace('"', '')
    print('原始csv路径：', csv_file_name)
    df = pd.read_csv(csv_file_name, low_memory=False)
    excel_file_name = csv_file_name.replace('.csv', '.xlsx')
    print('转换后的excel路径：', excel_file_name)
    df.to_excel(excel_file_name, index=False)


if __name__ == '__main__':
    while True:
        csv_file = input('请输入要解密的csv文件路径: ')
        start_time = time.time()
        csv_to_excel_fun(csv_file)
        end_time = time.time()
        duration = end_time - start_time
        print_text = 'CSV to EXCEL 转换完成！一共用时：{} 秒'.format(duration)
        print(print_text)


# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File:           convert_pdf_table_html.py
   Description:    提取PDF文件中的表格转换为html
   Author:        
   Create Date:    2020/05/12
-------------------------------------------------
   Modify:
                   2020/05/12:
-------------------------------------------------
"""

import camelot
from urllib import parse


def convert_pdf_table_html(pdf_file_path, save_file_path, table_index=None, **kwargs):
    """

    :param pdf_file_path:
    :param save_file_path:
    :param table_index:
    :param kwargs:
    :return:
    """


    pdf_file_path = pdf_file_path.strip()

    try:
        pdf_file_path_temp = parse.unquote(pdf_file_path)
        # print(pdf_file_path)
        # 获取文件名字
        # file_name = ''
        # if '\\' in pdf_file_path_temp:
        #     file_name = pdf_file_path_temp.split('\\')[-1].replace('.' + pdf_file_path_temp.split('\\')[-1].split('.')[-1], '')
        # elif '/' in pdf_file_path_temp:
        #     file_name = pdf_file_path_temp.split('/')[-1].replace('.' + pdf_file_path_temp.split('/')[-1].split('.')[-1], '')

        if 'http' in pdf_file_path and '%' not in pdf_file_path:
            tables = camelot.read_pdf(pdf_file_path.replace(pdf_file_path.split('/')[-1], parse.quote(pdf_file_path.split('/')[-1])), flavor='stream', **kwargs)
        else:
            tables = camelot.read_pdf(pdf_file_path, flavor='stream', **kwargs)

        # 转换所有表格
        if table_index is None:
            print(len(tables))
            x = 0
            for i in tables:
                i.df.to_html(save_file_path +  str(x) + '.html')
                x += 1

        #指定表格索引
        tables[table_index].df.to_html(save_file_path + '0' + '.html')
        return 'ok'
    except Exception as e:
        print(e)
        return 'fail'


if __name__ == '__main__':
    pdf_file_path = "./pdf/test.pdf"
    save_file_path = "./pdf"
    convert_pdf_table_html(pdf_file_path, save_file_path, -1, pages='all')